@@ -71,3 +71,6 @@ class Block:
 
 	def get_wildness(self, iteration, tick):
 		return self.wildness
+
+	def stop(self):
+		pass
