@@ -223,7 +223,6 @@ class Sequencer:
 			self.output_midi()
 			sys.exit(0)
 
-
 	def stop(self):
 		for instr in self.instruments:
-			instr.stop_playing_notes()
+			instr.stop()
