@@ -176,6 +176,9 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.startbutton, 
 			QtCore.SIGNAL("clicked()"), 
 			self.start_simulation)
+		self.connect(self.ui.stopbutton, 
+			QtCore.SIGNAL("clicked()"), 
+			self.stop_simulation)
 		self.connect(self.ui.addblockbutton,
 			QtCore.SIGNAL("clicked()"),
 			self.add_block)
@@ -479,13 +482,36 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			seq = Options.get_sequencer(o)
 			self.ui.stopbutton.setEnabled(True)
 			self.ui.startbutton.setEnabled(False)
-			seq.play()
 			self.lastmidi = o.midifile
+
+			self.seqthread  = SequencerThread(seq)
+			self.connect(self.seqthread, QtCore.SIGNAL("finished()"), self.seqstopped)
+			self.seqthread.start()
+
+
 		except Options.OptionError, err:
 			self.set_status("Error: " + str(err))
 
-		self.ui.startbutton.setEnabled(True)
+	def stop_simulation(self):
 		self.ui.stopbutton.setEnabled(False)
+		self.ui.startbutton.setEnabled(True)
+		self.seqthread.seq.stop()
+		self.seqthread.terminate()
+
+	def seqstopped(self):
+		self.ui.stopbutton.setEnabled(False)
+		self.ui.startbutton.setEnabled(True)
+		del self.seqthread
+
+
+class SequencerThread(QtCore.QThread):
+	def __init__(self, seq):
+		self.seq = seq
+		QtCore.QThread.__init__(self)
+
+	def run(self):
+		self.seq.play()
+
 
 app = QtGui.QApplication(argv)
 i = ImproviserMainWindow()
